@@ -35,11 +35,7 @@ class SignaldAPI(SignaldGeneratedAPI):
         """
         Stops receiving message for an phone 'username'.
         """
-        await self.get_response_and_wait_for(
-            request={"type": "unsubscribe", "username": username},
-            validator=lambda response: response.get("type") == "listen_stopped"
-            and response.get("data") == username,
-        )
+        await self.get_response({"type": "unsubscribe", "username": username})
 
     async def link(
         self, deviceName: str, username: str
